-----------------------------------------------------------------------------------------------
-- Client Lua Script for TrackMaster_SubdueIntl
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntl Module Definition
-----------------------------------------------------------------------------------------------
local TrackMaster_SubdueIntl = {} 
 
local strWeaponPattern = "(%S+)'s Weapon"	-- enUS
local strCancel = Apollo.GetString(1)
if strCancel == "Abbrechen" then 
	strWeaponPattern = "Waffe von (%S+)"	-- deDE
elseif strCancel == "Annuler" then
	strWeaponPattern = "Arme de (%S+)"		-- frFR
end

-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function TrackMaster_SubdueIntl:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    self.units = {}
	self.enabled = true
	self.lineNo = 1

    return o
end

function TrackMaster_SubdueIntl:Init()
    Apollo.RegisterAddon(self)
end
 

-----------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntl OnLoad
-----------------------------------------------------------------------------------------------
function TrackMaster_SubdueIntl:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("TrackMaster_SubdueIntl.xml")
	
	self.timer = ApolloTimer.Create(1.0, true, "OnTimer", self)
	
	Apollo.RegisterEventHandler("UnitCreated", "OnUnitCreated", self)	
end

function TrackMaster_SubdueIntl:OnSave(eLevel)
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then
        return nil
    end
	local saveData = { }
	saveData["Enabled"] = self.enabled
	saveData.lineNo = self.lineNo
	return saveData
end

function TrackMaster_SubdueIntl:OnRestore(eLevel, tData)
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then
		return nil
	end
	
	if tData["Enabled"] then
		self:Enable()
	else
		self:Disable()
	end

	if tData.lineNo ~= nil then
		self.lineNo = tData.lineNo
	end

	if self.tmConfig ~= nil then
		self.tmConfig:SetEnabled(self.enabled)
		self.tmConfig:SetLineNo(self.lineNo)
	end
end

-----------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntl GetAsyncLoadStatus
-----------------------------------------------------------------------------------------------
function TrackMaster_SubdueIntl:GetAsyncLoadStatus()

	-- check for external dependencies here
	if g_AddonsLoaded == nil then
		g_AddonsLoaded = {}
	end
	if not g_AddonsLoaded["TrackMaster"] then
		return Apollo.AddonLoadStatus.Loading
	end

	if self.xmlDoc:IsLoaded() then
		local trackMaster = Apollo.GetAddon("TrackMaster")
		self.tmConfig = trackMaster:AddToConfigMenu(trackMaster.Type.Track, "Subdue", {
			CanFire = false,
			CanEnable = true,
			IsChecked = self.enabled,
			OnEnableChanged = (function(isEnabled)
				if isEnabled then
					self:Enable()
				else
					self:Disable()
				end
			end),
			LineNo = self.lineNo,
			OnLineChanged = (function(lineNo)
				self.lineNo = lineNo
			end)
		})
		self.xmlDoc = nil
		
		-- register our Addon so others can wait for it if they want
		g_AddonsLoaded["TrackMaster_SubdueIntl"] = true
		
		return Apollo.AddonLoadStatus.Loaded
	end
	return Apollo.AddonLoadStatus.Loading 
end

-----------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntl Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here


function TrackMaster_SubdueIntl:CalculateDistance(vector)
	return math.sqrt(math.pow(vector.x, 2) + math.pow(vector.y, 2) + math.pow(vector.z, 2))
end

function TrackMaster_SubdueIntl:OnUnitCreated(unit)
	if unit:GetType() == "Pickup" then
		local playerName = GameLib.GetPlayerUnit():GetName();
		if string.match(unit:GetName(), strWeaponPattern) == playerName then
			Apollo.GetAddon("TrackMaster"):SetTarget(unit, -1, self.lineNo)
		end
	end
end

---------------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntlForm Functions
---------------------------------------------------------------------------------------------------

function TrackMaster_SubdueIntl:Enable()
	Apollo.RegisterEventHandler("UnitCreated", "OnUnitCreated", self)
	Apollo.RegisterEventHandler("UnitDestroyed", "OnUnitDestroyed", self)
	self.enabled = true
end

function TrackMaster_SubdueIntl:Disable()
	Apollo.RemoveEventHandler("UnitCreated", self)
	self.enabled = false
end

function TrackMaster_SubdueIntl:OnEnableChecked( wndHandler, wndControl, eMouseButton )
	self:Enable()
end

function TrackMaster_SubdueIntl:OnEnableUnChecked( wndHandler, wndControl, eMouseButton )
	self:Disable()
end

-----------------------------------------------------------------------------------------------
-- TrackMaster_SubdueIntl Instance
-----------------------------------------------------------------------------------------------
local TrackMaster_SubdueIntlInst = TrackMaster_SubdueIntl:new()
TrackMaster_SubdueIntlInst:Init()
